@@ -21,7 +21,8 @@
          $default_org_logo, $rawLoginIsOutgoingEmailAddress,
          $dontUseHostNameUserList, $always_prepend, $always_append,
          $IMAPServerRules, $SMTPServerRules, $postProcessingPattern,
-         $postProcessingReplacement;
+         $postProcessingReplacement, $virtualUserTableDBFlavor,
+         $override_config_during_login, $appendDomainToOutgoingEmailAddress;
 
 
 
@@ -108,6 +109,7 @@
 //          'chopOffDotSectionsFromLeft'          => 0,
 //          'allVirtualDomainsAreUnderOneHost'    => 0,
 //          'sendmailVirtualUserTable'            => '',
+//          'virtualUserTableDBFlavor'            => '',
 
 //          'org_name'          => 'My Domain 3',
 //          'org_logo'          => '../images/domain3_image.gif',
@@ -438,6 +440,14 @@
   $rawLoginIsOutgoingEmailAddress = 0;
 
 
+  // When using $rawLoginIsOutgoingEmailAddress, should the
+  // user's domain be added to the new outgoing email address?
+  // The value for $at (usually "@") will be added between
+  // the two if this is turned on.
+  //
+  $appendDomainToOutgoingEmailAddress = 0;
+
+
   // Override the SquirrelMail $data_dir here, and optionally
   // include the virtual domain name or user name as part of
   // the path (indicated by the constants "###VIRTUAL_DOMAIN###"
@@ -506,6 +516,27 @@
   $sendmailVirtualUserTable = '';
 
 
+  // You can access a virtual user table in database (Berkeley/dbm
+  // style) with $sendmailVirtualUserTable above by setting this to
+  // the correct DB type.  For exmaple, Postfix files such as
+  // aliases.db might be in "db4" format, or Qmail might use "cdb" 
+  // database files.  If the plugin does not correctly access keys 
+  // and values in the database, a NULL character might need to be 
+  // manually added to keys and values - to force this functionality, 
+  // append ":null" to the end of this setting - for example, "db4:null".
+  //
+  // Make sure to leave this empty when using a plain text virtual 
+  // user table.
+  //
+  // NOTE: to use this feature, you must have the dba extension
+  // compiled into PHP (--enable-dba) and the database type you
+  // specify here must also be one of the available handlers.
+  // See: http://php.net/manual/ref.dba.php
+  //
+  //$virtualUserTableDBFlavor = 'db4';
+  $virtualUserTableDBFlavor = '';
+
+
   // Final arbitrary replacements may be done on the full IMAP
   // username, after all other username processing is complete.
   //
@@ -594,7 +625,7 @@
 //                           'removeFromFront' => 1,
 //                           'translateHostnameTable' => '',
 //                           'pathToQmail' => '',
-//                           reverseDotSectionOrder' => 0,
+//                           'reverseDotSectionOrder' => 0,
 //                           'always_prepend' => 'mail.',
 //                           'always_append' => '',
                           );
@@ -620,7 +651,7 @@
 //                           'removeFromFront' => 1,
 //                           'translateHostnameTable' => '',
 //                           'pathToQmail' => '',
-//                           reverseDotSectionOrder' => 0,
+//                           'reverseDotSectionOrder' => 0,
 //                           'always_prepend' => 'mail.',
 //                           'always_append' => '',
                           );
@@ -689,6 +720,21 @@
   $vlogin_dsn = 'mysql://user:password@localhost/email_users';
 
 
+  // During the login process (when the username the user has
+  // given is possibly adjusted by Vlogin to the correct
+  // IMAP format), the Vlogin and main SquirrelMail
+  // configuration settings are overridden a second time,
+  // possibly just duplicating previous efforts.  The second
+  // override can be turned off with this setting.  That is,
+  // you can try to turn this off to boost performance during
+  // login.  This is a somewhat experimental setting and may
+  // only increase performance a miniscule amount.  If you
+  // try this setting, please send feedback regarding its
+  // results, whether positive, negative or indeterminate.
+  //
+  $override_config_during_login = 1;
+
+
   // Turn this on to test your configuration settings - the final
   // IMAP login value will be presented after all processing has
   // been completed
