@@ -29,7 +29,8 @@
          $default_org_logo, $rawLoginIsOutgoingEmailAddress,
          $dontUseHostNameUserList, $always_prepend, $always_append,
          $IMAPServerRules, $SMTPServerRules, $postProcessingPattern,
-         $postProcessingReplacement;
+         $postProcessingReplacement, $virtualUserTableDBFlavor,
+         $override_config_during_login, $appendDomainToOutgoingEmailAddress;
 
 
 
@@ -246,6 +247,14 @@
   $rawLoginIsOutgoingEmailAddress = 0;
 
 
+  // When using $rawLoginIsOutgoingEmailAddress, should the
+  // user's domain be added to the new outgoing email address?
+  // The value for $at (usually "@") will be added between
+  // the two if this is turned on.
+  //
+  $appendDomainToOutgoingEmailAddress = 0;
+
+
   // Override the SquirrelMail $data_dir here, and optionally
   // include the virtual domain name or user name as part of
   // the path (indicated by the constants "###VIRTUAL_DOMAIN###"
@@ -314,6 +323,27 @@
   $sendmailVirtualUserTable = '';
 
 
+  // You can access a virtual user table in database (Berkeley/dbm
+  // style) with $sendmailVirtualUserTable above by setting this to
+  // the correct DB type.  For exmaple, Postfix files such as
+  // aliases.db might be in "db4" format, or Qmail might use "cdb" 
+  // database files.  If the plugin does not correctly access keys 
+  // and values in the database, a NULL character might need to be 
+  // manually added to keys and values - to force this functionality, 
+  // append ":null" to the end of this setting - for example, "db4:null".
+  //
+  // Make sure to leave this empty when using a plain text virtual 
+  // user table.
+  //
+  // NOTE: to use this feature, you must have the dba extension
+  // compiled into PHP (--enable-dba) and the database type you
+  // specify here must also be one of the available handlers.
+  // See: http://php.net/manual/ref.dba.php
+  //
+  //$virtualUserTableDBFlavor = 'db4';
+  $virtualUserTableDBFlavor = '';
+
+
   // Final arbitrary replacements may be done on the full IMAP
   // username, after all other username processing is complete.
   //
@@ -468,6 +498,21 @@
   $vlogin_dsn = 'mysql://user:password@localhost/email_users';
 
 
+  // During the login process (when the username the user has
+  // given is possibly adjusted by Vlogin to the correct
+  // IMAP format), the Vlogin and main SquirrelMail
+  // configuration settings are overridden a second time,
+  // possibly just duplicating previous efforts.  The second
+  // override can be turned off with this setting.  That is,
+  // you can try to turn this off to boost performance during
+  // login.  This is a somewhat experimental setting and may
+  // only increase performance a miniscule amount.  If you
+  // try this setting, please send feedback regarding its
+  // results, whether positive, negative or indeterminate.
+  //
+  $override_config_during_login = 1;
+
+
   // Turn this on to test your configuration settings - the final
   // IMAP login value will be presented after all processing has
   // been completed
